# My Basic Calculator
**This package hepls you carry out the four basic arithmetic operations**

# Getting started
## Installing the package
> pip install thecalcpack

## Using the package
`from packagingtutorials import thecalcpack`


# Functions Provided
1. add(a,b)
**This function adds two arguments a and b and returns them.**

2. sub(a,b)
**This function subtracts two arguments a and b and returns them.**

3. mul(a,b)
**This function multiplies two arguments a and b and returns them.**

4. div(a,b)
**This functions divides two arguments a and b and returns them.**

